module.exports = defineTest({
	description: 'correctly deshadows destructured function parameters (#1008)'
});
